@@ -1,4 +1,4 @@
-use nettu_scheduler_domain::{Calendar, CalendarSettings, Metadata, ID};
+use nettu_scheduler_domain::{Calendar, CalendarSettings, Metadata, SyncedCalendar, ID};
 use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Deserialize, Serialize, Clone)]
@@ -7,6 +7,7 @@ pub struct CalendarDTO {
     pub id: ID,
     pub user_id: ID,
     pub settings: CalendarSettingsDTO,
+    pub synced: Vec<SyncedCalendar>,
     pub metadata: Metadata,
 }
 
@@ -23,6 +24,7 @@ impl CalendarDTO {
             id: calendar.id.clone(),
             user_id: calendar.user_id.clone(),
             settings: CalendarSettingsDTO::new(&calendar.settings),
+            synced: calendar.synced,
             metadata: calendar.metadata,
         }
     }
