@@ -95,7 +95,7 @@ pub mod create_service_event_intend {
     #[derive(Deserialize, Serialize)]
     #[serde(rename_all = "camelCase")]
     pub struct APIResponse {
-        selected_host: UserDTO,
+        pub selected_host: UserDTO,
     }
 
     impl APIResponse {
